import React, { useState, useEffect } from 'react';
import {
  Table,
  Spin,
  Modal,
  Form,
  Input,
  Space,
  Button,
  Popconfirm,
  notification,
  message,
} from 'antd';
import { get } from '@/services/index';
import styles from './WebDic.less';

const WebDic = () => {
  const [loading, setLoading] = useState(false);
  const [level, setLevel] = useState(1);
  const [addVisible, setAddVisible] = useState(false);
  const [editVisible, setEditVisible] = useState(false);
  const [data, setData] = useState([]); // 一级条目
  const [subData, setSubData] = useState([]); // 二级条目
  const [select, setSelect] = useState({}); // 当前选中条目,可以是一级/二级条目，修改/删除时设置
  const [selectID, setSelectID] = useState('-1'); // 当前选中一级条目的ID，添加条目时使用
  const [addForm] = Form.useForm();
  const [editForm] = Form.useForm();

  const columns = [
    {
      title: '名称',
      dataIndex: 'nodeName',
      key: 'nodeName',
      width: 300,
    },
    {
      title: '值',
      dataIndex: 'nodeValue',
      key: 'nodeValue',
      render: record => {
        if (!record) {
          return '-';
        }
        return record;
      },
    },
    {
      title: '操作',
      key: 'action',
      width: 200,
      render: record => (
        <Space>
          <Button
            type="primary"
            size="small"
            onClick={e => {
              e.stopPropagation();
              setSelect(record);
              setEditVisible(true);
              editForm.setFieldsValue({
                nodeName: record.nodeName,
                nodeValue: record.nodeValue,
              });
            }}
          >
            修改
          </Button>
          <Popconfirm
            title="是否删除该数据？"
            okText="确认"
            cancelText="取消"
            onConfirm={submitDelete}
          >
            <Button
              size="small"
              danger
              onClick={e => {
                e.stopPropagation();
                setSelect(record);
              }}
            >
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  useEffect(() => {
    getData('-1');
  }, []);
  // 根据父节点nodeID（即parentID）获取数据，一级条目parentID = -1
  const getData = value => {
    setLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/D_GetDataDictionaryList`, {
      _version: 9999,
      _dc: new Date().getTime(),
      nodeID: value,
      key: '',
    })
      .then(res => {
        if (res) {
          if (res.length > 0) {
            res.map(item => {
              item.key = item.nodeID;
              return item;
            });
          }
          // value为 -1 时获取一级条目数据，否则获取二级条目数据
          if (value === '-1') {
            setData(res); // 设置一级条目
            setSelect(res[0]); // 默认当前选中一级条目第一条
            setSelectID(res[0].nodeID); // 设置选中的一级条目ID，用于添加二级条目
          } else if (value) {
            setSubData(res); // 设置二级条目,res为空[]时也要设置
          }
          // 获取二级条目数据，默认一级条目第一条，递归一次（条件parentID === '-1'）
          if (res && res[0] && res[0].parentID === '-1') {
            getData(res[0].nodeID);
          }
        } else {
          notification.error({
            message: '获取失败',
            description: res.message,
          });
        }
        setLoading(false);
      })
      .catch(err => {
        setLoading(false);
        message.error(err);
      });
  };
  const setRowClassName = record =>
    record.nodeID === select.nodeID ? styles.clickRowStyle : '';

  // 提交-添加
  const submitAdd = value => {
    const nodeName = addForm.getFieldValue('nodeName');
    const nodeValue = addForm.getFieldValue('nodeValue');
    if (nodeName) {
      get(`/Cityinterface/rest/services/OMS.svc/D_AddDataDictionary`, {
        _version: 9999,
        _dc: new Date().getTime(),
        nodeID: value,
        nodeName,
        nodeValue,
      })
        .then(res => {
          if (res.success) {
            setAddVisible(false);
            if (level === 1) {
              getData('-1');
            } else {
              getData(selectID);
            }
            notification.success({
              message: '提交成功',
            });
          } else {
            notification.error({
              message: '提交失败',
              description: res.message,
            });
          }
        })
        .catch(err => {
          message.error(err);
        });
    } else {
      notification.error({
        message: '提交失败',
        description: '名称不能为空',
      });
    }
  };
  // 提交-编辑
  const submitEdit = () => {
    const nodeName = editForm.getFieldValue('nodeName');
    const nodeValue = editForm.getFieldValue('nodeValue');
    if (nodeName) {
      get(`/Cityinterface/rest/services/OMS.svc/D_EditDataDictionary`, {
        _version: 9999,
        _dc: new Date().getTime(),
        nodeID: select.nodeID,
        nodeName,
        nodeValue,
      })
        .then(res => {
          if (res.success) {
            setEditVisible(false);
            getData(select.parentID);
            notification.success({
              message: '提交成功',
            });
          } else {
            notification.error({
              message: '提交失败',
              description: res.message,
            });
          }
        })
        .catch(err => {
          message.error(err);
        });
    } else {
      notification.error({
        message: '提交失败',
        description: '名称不能为空',
      });
    }
  };

  const submitDelete = () => {
    get(`/Cityinterface/rest/services/OMS.svc/D_DeleteDataDictionary`, {
      _version: 9999,
      _dc: new Date().getTime(),
      nodeID: select.nodeID,
    })
      .then(res => {
        if (res.success) {
          getData(select.parentID);
          notification.success({
            message: '删除成功',
          });
        } else {
          notification.error({
            message: '删除失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };

  return (
    <div className={styles.WebDic}>
      <Spin spinning={loading} tip="loading...">
        <div style={{ marginBottom: '10px', fontSize: '16px' }}>
          <span style={{ padding: '0 10px' }}>一级条目</span>
          <Button
            type="primary"
            size="small"
            onClick={() => {
              setLevel(1);
              setAddVisible(true);
              addForm.resetFields();
            }}
          >
            添加
          </Button>
        </div>
        {/* 一级条目 表格 */}
        <Table
          size="small"
          bordered
          columns={columns}
          dataSource={data}
          scroll={{ x: 'max-content' }}
          rowClassName={setRowClassName}
          onRow={record => ({
            onClick: () => {
              getData(record.nodeID);
              setSelect(record);
              setSelectID(record.nodeID);
            },
          })}
          pagination={{
            showTotal: (total, range) =>
              `第${range[0]}-${range[1]} 条/共 ${total} 条`,
            pageSizeOptions: [10, 20, 50, 100],
            showQuickJumper: true,
            showSizeChanger: true,
          }}
        />
        <hr color="#cfe7fd" />
        <div style={{ marginBottom: '10px', fontSize: '16px' }}>
          <span style={{ padding: '0 10px' }}>二级条目</span>
          <Button
            type="primary"
            size="small"
            onClick={() => {
              setLevel(2);
              setAddVisible(true);
              addForm.resetFields();
            }}
          >
            添加
          </Button>
        </div>
        {/* 二级条目 表格 */}
        <Table
          size="small"
          bordered
          columns={columns}
          dataSource={subData}
          scroll={{ x: 'max-content' }}
          pagination={{
            showTotal: (total, range) =>
              `第${range[0]}-${range[1]} 条/共 ${total} 条`,
            pageSizeOptions: [10, 20, 50, 100],
            showQuickJumper: true,
            showSizeChanger: true,
          }}
        />
      </Spin>

      {/* 添加 */}
      <Modal
        title={level === 1 ? '添加一级条目' : '添加二级条目'}
        visible={addVisible}
        onOk={() => {
          if (level === 1) {
            submitAdd('-1');
          } else {
            submitAdd(selectID);
          }
        }}
        onCancel={() => {
          setAddVisible(false);
        }}
        okText="确认"
        cancelText="取消"
      >
        <Form form={addForm} labelCol={{ span: 3 }}>
          <Form.Item
            name="nodeName"
            label="名称"
            rules={[{ required: true, message: '不能为空' }]}
          >
            <Input placeholder="请输入名称" />
          </Form.Item>
          <Form.Item name="nodeValue" label="值">
            <Input placeholder="请输入值" />
          </Form.Item>
        </Form>
      </Modal>
      {/* 修改 */}
      <Modal
        title={select.parentID === '-1' ? '修改一级条目' : '修改二级条目'}
        visible={editVisible}
        onOk={submitEdit}
        onCancel={() => {
          setEditVisible(false);
        }}
        okText="确认"
        cancelText="取消"
      >
        <Form form={editForm} labelCol={{ span: 3 }}>
          <Form.Item
            name="nodeName"
            label="名称"
            rules={[{ required: true, message: '不能为空' }]}
          >
            <Input placeholder="请输入名称" />
          </Form.Item>
          <Form.Item name="nodeValue" label="值">
            <Input placeholder="请输入值" />
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default WebDic;
