import { getConfigContent, saveConfigContent } from '@/services/webConfig/api';
import { Button, Input, Modal, notification } from 'antd';
import React, { Children, useState } from 'react';

const ConfigWrapper = props => {
  const { value, children, ...rest } = props;
  const [text, setText] = useState('');
  const [visible, setVisible] = useState(false);

  const showModal = () => {
    if (!value) {
      notification.warning({
        message: '请先填写配置文件名称',
        duration: 3,
      });
      return;
    }
    getConfigContent(value)
      .then(res => {
        if (res.success) {
          setText(res.message);
        }
      })
      .catch(e => {
        console.error(e);
      });
    setVisible(true);
  };

  const handleOk = () => {
    let content;
    let err = false;
    try {
      content = JSON.parse(text);
    } catch (error) {
      notification.error({
        message: '编辑内容必须是json格式',
        duration: 5,
      });
      err = true;
    }
    if (!err) {
      saveConfigContent(JSON.stringify(JSON.parse(text), null, 4))
        .then(res => {
          if (res.success) {
            notification.success({
              message: '保存成功',
              duration: 3,
            });
          }
        })
        .catch(error => {
          console.error(error);
        });
    }
  };

  return (
    <div style={{ display: 'flex' }}>
      {Children.map(children, child => React.cloneElement(child, { ...rest }))}
      {<Button onClick={showModal}>编辑</Button>}
      <Modal
        title="编辑配置"
        visible={visible}
        onOk={handleOk}
        maskClosable={false}
        onCancel={() => setVisible(false)}
      >
        <Input.TextArea
          value={text}
          onChange={e => {
            setText(e.target.value);
          }}
          rows={5}
        />
      </Modal>
    </div>
  );
};
export default ConfigWrapper;
